Package: rmarkdown
Type: Package
Title: Dynamic Documents for R
Version: 2.11
Authors@R: c(
  person("JJ", "Allaire", role = "aut", email = "jj@rstudio.com"),
  person("Yihui", "Xie", role = c("aut", "cre"), email = "xie@yihui.name", comment = c(ORCID = "0000-0003-0645-5666")),
  person("Jonathan", "McPherson", role = "aut", email = "jonathan@rstudio.com"),
  person("Javier", "Luraschi", role = "aut", email = "javier@rstudio.com"),
  person("Kevin", "Ushey", role = "aut", email = "kevin@rstudio.com"),
  person("Aron", "Atkins", role = "aut", email = "aron@rstudio.com"),
  person("Hadley", "Wickham", role = "aut", email = "hadley@rstudio.com"),
  person("Joe", "Cheng", role = "aut", email = "joe@rstudio.com"),
  person("Winston", "Chang", role = "aut", email = "winston@rstudio.com"),
  person("Richard", "Iannone", role = "aut", email = "rich@rstudio.com", comment = c(ORCID = "0000-0003-3925-190X")),
  #
  # Contributors, ordered alphabetically by first name
  person("Andrew", "Dunning", role = "ctb", comment = c(ORCID = "0000-0003-0464-5036")),
  person("Atsushi", "Yasumoto", role = c("ctb", "cph"),
         comment = c(ORCID = "0000-0002-8335-495X",
                     cph = "Number sections Lua filter")),
  person("Barret", "Schloerke", role = "ctb"),
  person("Carson", "Sievert", role = "ctb", comment = c(ORCID = "0000-0002-4958-2844")),
  person("Christophe", "Dervieux", role = "ctb"),
  person("Devon", "Ryan", role = "ctb", email = "dpryan79@gmail.com", comment = c(ORCID = "0000-0002-8549-0971")),
  person("Frederik", "Aust", role = "ctb", email = "frederik.aust@uni-koeln.de", comment = c(ORCID = "0000-0003-4900-788X")),
  person("Jeff", "Allen", role = "ctb", email = "jeff@rstudio.com"),
  person("JooYoung", "Seo", role="ctb", comment = c(ORCID = "0000-0002-4064-6012")),
  person("Malcolm", "Barrett", role = "ctb"),
  person("Rob", "Hyndman", role = "ctb", email = "Rob.Hyndman@monash.edu"),
  person("Romain", "Lesur", role = "ctb"),
  person("Roy", "Storey", role = "ctb"),
  person("Ruben", "Arslan", role = "ctb", email = "ruben.arslan@uni-goettingen.de"),
  person("Sergio", "Oller", role = "ctb"),
  #
  # Copyright holders
  person(family = "RStudio, PBC", role = "cph"),
  person(family = "jQuery UI contributors", role = c("ctb", "cph"),
         comment = "jQuery UI library; authors listed in inst/rmd/h/jqueryui-AUTHORS.txt"),
  person("Mark", "Otto", role = "ctb",
         comment = "Bootstrap library"),
  person("Jacob", "Thornton", role = "ctb",
         comment = "Bootstrap library"),
  person(family = "Bootstrap contributors", role = "ctb",
         comment = "Bootstrap library"),
  person(family = "Twitter, Inc", role = "cph",
         comment = "Bootstrap library"),
  person("Alexander", "Farkas", role = c("ctb", "cph"),
         comment = "html5shiv library"),
  person("Scott", "Jehl", role = c("ctb", "cph"),
         comment = "Respond.js library"),
  person("Ivan", "Sagalaev", role = c("ctb", "cph"),
         comment = "highlight.js library"),
  person("Greg", "Franko", role = c("ctb", "cph"),
         comment = "tocify library"),
  person("John", "MacFarlane", role = c("ctb", "cph"),
         comment = "Pandoc templates"),
  person(family = "Google, Inc.", role = c("ctb", "cph"),
         comment = "ioslides library"),
  person("Dave", "Raggett", role = "ctb",
         comment = "slidy library"),
  person(family = "W3C", role = "cph",
         comment = "slidy library"),
  person("Dave", "Gandy", role = c("ctb", "cph"),
         comment = "Font-Awesome"),
  person("Ben", "Sperry", role = "ctb",
         comment = "Ionicons"),
  person(family = "Drifty", role = "cph",
         comment = "Ionicons"),
  person("Aidan", "Lister", role = c("ctb", "cph"), 
         comment = "jQuery StickyTabs"),
  person("Benct Philip", "Jonsson", role = c("ctb", "cph"), 
         comment = "pagebreak Lua filter"),
  person("Albert", "Krewinkel", role = c("ctb", "cph"), 
         comment = "pagebreak Lua filter")
  )
Maintainer: Yihui Xie <xie@yihui.name>
Description: Convert R Markdown documents into a variety of formats.
Depends: R (>= 3.0)
Imports: tools, utils, knitr (>= 1.22), yaml (>= 2.1.19), htmltools (>=
        0.3.5), evaluate (>= 0.13), jsonlite, tinytex (>= 0.31), xfun
        (>= 0.21), jquerylib, methods, stringr (>= 1.2.0)
Suggests: shiny (>= 1.6.0), tufte, testthat (>= 3.0.0), digest,
        dygraphs, vctrs, tibble, fs, rsconnect, withr (>= 2.4.2), bslib
        (>= 0.2.5.1), sass (>= 0.4.0)
SystemRequirements: pandoc (>= 1.14) - http://pandoc.org
URL: https://github.com/rstudio/rmarkdown,
        https://pkgs.rstudio.com/rmarkdown/
BugReports: https://github.com/rstudio/rmarkdown/issues
License: GPL-3
RoxygenNote: 7.1.2
Encoding: UTF-8
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2021-09-14 13:25:46 UTC; yihui
Author: JJ Allaire [aut],
  Yihui Xie [aut, cre] (<https://orcid.org/0000-0003-0645-5666>),
  Jonathan McPherson [aut],
  Javier Luraschi [aut],
  Kevin Ushey [aut],
  Aron Atkins [aut],
  Hadley Wickham [aut],
  Joe Cheng [aut],
  Winston Chang [aut],
  Richard Iannone [aut] (<https://orcid.org/0000-0003-3925-190X>),
  Andrew Dunning [ctb] (<https://orcid.org/0000-0003-0464-5036>),
  Atsushi Yasumoto [ctb, cph] (<https://orcid.org/0000-0002-8335-495X>,
    Number sections Lua filter),
  Barret Schloerke [ctb],
  Carson Sievert [ctb] (<https://orcid.org/0000-0002-4958-2844>),
  Christophe Dervieux [ctb],
  Devon Ryan [ctb] (<https://orcid.org/0000-0002-8549-0971>),
  Frederik Aust [ctb] (<https://orcid.org/0000-0003-4900-788X>),
  Jeff Allen [ctb],
  JooYoung Seo [ctb] (<https://orcid.org/0000-0002-4064-6012>),
  Malcolm Barrett [ctb],
  Rob Hyndman [ctb],
  Romain Lesur [ctb],
  Roy Storey [ctb],
  Ruben Arslan [ctb],
  Sergio Oller [ctb],
  RStudio, PBC [cph],
  jQuery UI contributors [ctb, cph] (jQuery UI library; authors listed in
    inst/rmd/h/jqueryui-AUTHORS.txt),
  Mark Otto [ctb] (Bootstrap library),
  Jacob Thornton [ctb] (Bootstrap library),
  Bootstrap contributors [ctb] (Bootstrap library),
  Twitter, Inc [cph] (Bootstrap library),
  Alexander Farkas [ctb, cph] (html5shiv library),
  Scott Jehl [ctb, cph] (Respond.js library),
  Ivan Sagalaev [ctb, cph] (highlight.js library),
  Greg Franko [ctb, cph] (tocify library),
  John MacFarlane [ctb, cph] (Pandoc templates),
  Google, Inc. [ctb, cph] (ioslides library),
  Dave Raggett [ctb] (slidy library),
  W3C [cph] (slidy library),
  Dave Gandy [ctb, cph] (Font-Awesome),
  Ben Sperry [ctb] (Ionicons),
  Drifty [cph] (Ionicons),
  Aidan Lister [ctb, cph] (jQuery StickyTabs),
  Benct Philip Jonsson [ctb, cph] (pagebreak Lua filter),
  Albert Krewinkel [ctb, cph] (pagebreak Lua filter)
Repository: CRAN
Date/Publication: 2021-09-14 14:10:02 UTC
Built: R 4.1.1; ; 2021-09-15 11:07:40 UTC; windows
