Package: codemetar
Type: Package
Title: Generate 'CodeMeta' Metadata for R Packages
Version: 0.1.6
Authors@R:
    c(person(given = "Carl",
             family = "Boettiger",
             role = c("aut", "cre", "cph"),
             email = "cboettig@gmail.com",
             comment = c(ORCID = "0000-0002-1642-628X")),
      person(given = "Anna",
             family = "Krystalli",
             role = c("rev", "ctb"),
             comment = c(ORCID = "0000-0002-2378-4915")),
      person(given = "Toph",
             family = "Allen",
             role = "rev",
             comment = c(ORCID = "0000-0003-4580-091X")),
      person(given = "Maëlle",
             family = "Salmon",
             role = c("ctb", "aut"),
             comment = c(ORCID = "0000-0002-2815-0399")),
      person(given = "rOpenSci",
             role = "fnd",
             comment = "https://ropensci.org/"),
      person(given = "Katrin",
             family = "Leinweber",
             role = "ctb"),
      person(given = "Noam",
             family = "Ross",
             role = "ctb"),
      person(given = "Arfon",
             family = "Smith",
             role = "ctb"))
Description: The 'Codemeta' Project defines a 'JSON-LD' format for describing
  software metadata, as detailed at <https://codemeta.github.io>. This package
  provides utilities to generate, parse, and modify 'codemeta.json' files
  automatically for R packages, as well as tools and examples for working with
  'codemeta.json' 'JSON-LD' more generally.
License: GPL-3
URL: https://bitbucket.org/ropensci/codemetar, https://ropensci.github.io/codemetar
BugReports: https://github.com/ropensci/codemetar/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1.9000
Depends: R (>= 3.0.0)
Imports:
    jsonlite (>= 1.3),
    jsonld,
    git2r,
    devtools,
    memoise,
    methods,
    stats,
    stringi,
    readr,
    desc,
    usethis,
    whisker,
    tibble,
    crul,
    gh,
    stringr,
    sessioninfo,
    purrr
Suggests:
    testthat,
    jsonvalidate,
    covr,
    knitr,
    rmarkdown,
    magrittr,
    xml2,
    dplyr (>= 0.7.0),
    printr
VignetteBuilder: knitr
X-schema.org-keywords: metadata, codemeta, ropensci, citation, credit, linked-data
X-schema.org-isPartOf: https://ropensci.org
