Package: codemetar
Type: Package
Title: Generate 'CodeMeta' Metadata for R Packages
Version: 0.1.6
Author: Jane Doo
Maintainer: John Ok <email@email.edu>, Jane Doe <email2@email.edu>
Description: The 'Codemeta' Project defines a 'JSON-LD' format for describing
  software metadata, as detailed at <https://codemeta.github.io>. This package
  provides utilities to generate, parse, and modify 'codemeta.json' files
  automatically for R packages, as well as tools and examples for working with
  'codemeta.json' 'JSON-LD' more generally.
License: GPL-3
URL: https://github.com/ropensci/codemetar, https://ropensci.github.io/codemetar
BugReports: https://github.com/ropensci/codemetar/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1.9000
Depends: R (>= 3.0.0)
Imports:
    jsonlite (>= 1.3),
    jsonld,
    git2r,
    devtools,
    memoise,
    methods,
    stats,
    stringi,
    readr,
    desc,
    usethis,
    whisker,
    tibble,
    crul,
    gh,
    stringr,
    sessioninfo,
    purrr
Suggests:
    testthat,
    jsonvalidate,
    covr,
    knitr,
    rmarkdown,
    magrittr,
    xml2,
    dplyr (>= 0.7.0),
    printr
VignetteBuilder: knitr
X-schema.org-keywords: metadata, codemeta, ropensci, citation, credit, linked-data
X-schema.org-isPartOf: https://ropensci.org
