# Generated by roxygen2: do not edit by hand

export("%>%")
export(create_codemeta)
export(extract_badges)
export(give_opinions)
export(write_codemeta)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,read_json)
importFrom(jsonlite,toJSON)
importFrom(magrittr,"%>%")
importFrom(memoise,memoise)
importFrom(methods,is)
importFrom(pingr,is_online)
importFrom(purrr,map_lgl)
importFrom(utils,as.person)
importFrom(utils,read.csv)
