
<table class="table"><thead><tr class="header">
<th align="left">Release</th>
<th align="left">Usage</th>
<th align="left">Development</th>
</tr></thead>
<tbody>
<tr class="odd">
<td align="left"><a href="https://doi.org/"><img src="http://joss.theoj.org/papers.svg" alt="JOSS"></a></td>
<td align="left"><a href="https://www.gnu.org/licenses/gpl-3.0.en.html"><img src="https://img.shields.io/badge/licence-GPL--3-blue.svg" alt="Licence"></a></td>
<td align="left"><a href="https://ci.appveyor.com/project/fakeorg/fakepackage"><img src="https://ci.appveyor.com/api/projects/status/4ypc9xnmqt70j94e?svg=true&amp;branch=master" alt="AppVeyor"></a></td>
</tr>
<tr class="even">
<td align="left"><a href="https://github.com/fakeorg/onboarding/issues/156"><img src="https://badges.fakeorg.org/156_status.svg" alt="fakeorg"></a></td>
<td align="left"><a href="https://cran.r-project.org/"><img src="https://img.shields.io/badge/R%3E%3D-3.2.0-blue.svg" alt="Project Status: Active – The project has reached a stable, usable state and is being actively developed."></a></td>
<td align="left"><a href="https://travis-ci.org/fakeorg/fakepackage"><img src="https://travis-ci.org/fakeorg/fakepackage.svg?branch=master" alt="Travis"></a></td>
</tr>
<tr class="odd">
<td align="left"><a href="http://cran.r-project.org/package=fakepackage"><img src="http://www.r-pkg.org/badges/version/fakepackage" alt="CRAN"></a></td>
<td align="left"><a href="http://cran.rstudio.com/package=fakepackage"><img src="http://cranlogs.r-pkg.org/badges/fakepackage" alt="downloads"></a></td>
<td align="left"><a href="https://codecov.io/github/fakeorg/fakepackage?branch=master"><img src="https://codecov.io/github/fakeorg/fakepackage/coverage.svg?branch=master" alt="Codecov"></a></td>
</tr>
<tr class="even">
<td align="left"><a href="https://zenodo.org/badge/latestdoi/82609103"><img src="https://zenodo.org/badge/82609103.svg" alt="Zenodo"></a></td>
<td align="left"></td>
<td align="left"></td>
</tr>
</tbody>
</table>
<br>


[![fakeorg_footer](http://fakeorg.org/public_images/github_footer.png)](https://fakeorg.org)
